# openseesboard
A placeholder for openseesboard python package

## Installation
```pip install openseesboard```



## License

© 2021 Mohsen Azimi

This repository is licensed under the MIT license. See LICENSE for details.